==> unixODBC-2.0.5.tar.gz: unixODBC-2.0.5/Drivers/txt/SQLPrepare.c <==
/**********************************************************************
 * SQLPrepare
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 **********************************************************************/

#include "driver.h"

SQLRETURN SQLPrepare(	SQLHSTMT    hDrvStmt,
						SQLCHAR     *szSqlStr,
						SQLINTEGER  nSqlStrLength )
{	
	return SQLPrepare_( hDrvStmt, szSqlStr, nSqlStrLength );
}

SQLRETURN SQLPrepare_(	SQLHSTMT    hDrvStmt,
					SQLCHAR     *szSqlStr,
					SQLINTEGER  nSqlStrLength )
{	
    HDRVSTMT 	hStmt		= (HDRVSTMT)hDrvStmt;

	/* SANITY CHECKS */
	if ( !hStmt )
		return SQL_INVALID_HANDLE;

	sprintf( hStmt->szSqlMsg, "hStmt = $%08lX", hStmt );
	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );

	if ( !szSqlStr )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No SQL to process" );
		return SQL_ERROR;
	}

	if ( hStmt->pszQuery )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR Statement already in use." );
		return SQL_ERROR;
	}

	/***************************************
	 * DO WHAT WE HAVE TO DO FOR THE DBMS SELECT OR WHAT EVER
	 ***************************************/
/*
	if ( !sqiPrepare( hStmt->hStmtExtras->hStmt, szSqlStr ) )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->hStmtExtras->hStmt->szMsg );
		return SQL_ERROR;
	}
*/
	hStmt->pszQuery = (char *)strdup( szSqlStr );

	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_INFO, LOG_INFO, "SQL_SUCCESS" );
	return SQL_SUCCESS;
}

==> unixODBC-2.0.7.tar.gz: unixODBC-2.0.7/Drivers/txt/SQLPrepare.c <==
/**********************************************************************
 * SQLPrepare
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 **********************************************************************/

#include "driver.h"

SQLRETURN SQLPrepare_(	SQLHSTMT    hDrvStmt,
    					SQLCHAR     *szSqlStr,
    					SQLINTEGER  nSqlStrLength )
{	
    HDRVSTMT 	hStmt		= (HDRVSTMT)hDrvStmt;
    
	/* SANITY CHECKS */
	if ( !hStmt )
		return SQL_INVALID_HANDLE;

	sprintf( hStmt->szSqlMsg, "hStmt = %p", hStmt );
	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );

	if ( !szSqlStr )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No SQL to process" );
		return SQL_ERROR;
	}

	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, szSqlStr );

/********************************************************/
/* DRIVER SPECIFIC               						*/
    nSqlStrLength = 0; /* GET RID OF COMPILE WARNING MESSAGE */
    ResetStmt_( hStmt );
	hStmt->pszQuery = (char *)strdup( szSqlStr );

	sqpOpen( hStmt->pszQuery, &(hStmt->pszQuery[strlen(hStmt->pszQuery)]) );

	if ( sqpParse() )	
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, sqpError() );
		sqpClose();
        free( hStmt->pszQuery );
        hStmt->pszQuery	= NULL;
		return SQL_ERROR;
	}
    hStmt->hStmtExtras->hParsedSQL = sqpAdoptParsedSQL();

    sqpClose();
/********************************************************/

	logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_INFO, LOG_INFO, "SQL_SUCCESS" );
	return SQL_SUCCESS;
}




SQLRETURN SQLPrepare(	SQLHSTMT    hDrvStmt,
						SQLCHAR     *szSqlStr,
						SQLINTEGER  nSqlStrLength )
{	
	return SQLPrepare_( hDrvStmt, szSqlStr, nSqlStrLength );
}
